@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2018 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2017-2019 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #ifndef TAO_PEGTL_CSTREAM_INPUT_HPP
@@ -16,13 +16,13 @@ namespace tao
 {
    namespace TAO_PEGTL_NAMESPACE
    {
-      template< typename Eol = eol::lf_crlf >
+      template< typename Eol = eol::lf_crlf, std::size_t Chunk = 64 >
       struct cstream_input
-         : buffer_input< internal::cstream_reader, Eol >
+         : buffer_input< internal::cstream_reader, Eol, std::string, Chunk >
       {
          template< typename T >
          cstream_input( std::FILE* in_stream, const std::size_t in_maximum, T&& in_source )
-            : buffer_input< internal::cstream_reader, Eol >( std::forward< T >( in_source ), in_maximum, in_stream )
+            : buffer_input< internal::cstream_reader, Eol, std::string, Chunk >( std::forward< T >( in_source ), in_maximum, in_stream )
          {
          }
       };
