@@ -1,4 +1,4 @@
-// Copyright (c) 2016-2018 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2016-2019 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #ifndef TAO_PEGTL_REWIND_MODE_HPP
@@ -12,9 +12,14 @@ namespace tao
    {
       enum class rewind_mode : char
       {
-         ACTIVE,
-         REQUIRED,
-         DONTCARE
+         active,
+         required,
+         dontcare,
+
+         // Compatibility, remove with 3.0.0
+         ACTIVE = active,
+         REQUIRED = required,
+         DONTCARE = dontcare
       };
 
    }  // namespace TAO_PEGTL_NAMESPACE
